v1alpha3

package
v0.0.0-...-e215152 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2026 License: Apache-2.0 Imports: 11 Imported by: 2

Documentation

Overview

Code generated by protoc-gen-deepcopy. DO NOT EDIT.

Code generated by protoc-gen-jsonshim. DO NOT EDIT.

Code generated by protoc-gen-deepcopy. DO NOT EDIT.

Code generated by protoc-gen-jsonshim. DO NOT EDIT.

Code generated by protoc-gen-deepcopy. DO NOT EDIT.

Code generated by protoc-gen-jsonshim. DO NOT EDIT.

Index

Constants

This section is empty.

Variables

var (
	ClientTLSSettings_TLSmode_name = map[int32]string{
		0: "DISABLE",
		1: "MUTUAL",
		2: "DUBBO_MUTUAL",
	}
	ClientTLSSettings_TLSmode_value = map[string]int32{
		"DISABLE":      0,
		"MUTUAL":       1,
		"DUBBO_MUTUAL": 2,
	}
)

Enum value maps for ClientTLSSettings_TLSmode.

var (
	DestinationRuleMarshaler   = &jsonpb.Marshaler{}
	DestinationRuleUnmarshaler = &jsonpb.Unmarshaler{AllowUnknownFields: true}
)
var (
	MeshServiceMarshaler   = &jsonpb.Marshaler{}
	MeshServiceUnmarshaler = &jsonpb.Unmarshaler{AllowUnknownFields: true}
)
var (
	VirtualServiceMarshaler   = &jsonpb.Marshaler{}
	VirtualServiceUnmarshaler = &jsonpb.Unmarshaler{AllowUnknownFields: true}
)
var File_networking_v1alpha3_destination_rule_proto protoreflect.FileDescriptor
var File_networking_v1alpha3_mesh_service_proto protoreflect.FileDescriptor
var File_networking_v1alpha3_virtual_service_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type ClientTLSSettings

type ClientTLSSettings struct {

	// Indicates whether connections to this port should be secured
	// using TLS. The value of this field determines how TLS is enforced.
	Mode ClientTLSSettings_TLSmode `protobuf:"varint,1,opt,name=mode,proto3,enum=dubbo.networking.v1alpha3.ClientTLSSettings_TLSmode" json:"mode,omitempty"`
	// contains filtered or unexported fields
}

func (*ClientTLSSettings) DeepCopy

func (in *ClientTLSSettings) DeepCopy() *ClientTLSSettings

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClientTLSSettings. Required by controller-gen.

func (*ClientTLSSettings) DeepCopyInterface

func (in *ClientTLSSettings) DeepCopyInterface() interface{}

DeepCopyInterface is an autogenerated deepcopy function, copying the receiver, creating a new ClientTLSSettings. Required by controller-gen.

func (*ClientTLSSettings) DeepCopyInto

func (in *ClientTLSSettings) DeepCopyInto(out *ClientTLSSettings)

DeepCopyInto supports using ClientTLSSettings within kubernetes types, where deepcopy-gen is used.

func (*ClientTLSSettings) Descriptor deprecated

func (*ClientTLSSettings) Descriptor() ([]byte, []int)

Deprecated: Use ClientTLSSettings.ProtoReflect.Descriptor instead.

func (*ClientTLSSettings) GetMode

func (*ClientTLSSettings) MarshalJSON

func (this *ClientTLSSettings) MarshalJSON() ([]byte, error)

MarshalJSON is a custom marshaler for ClientTLSSettings

func (*ClientTLSSettings) ProtoMessage

func (*ClientTLSSettings) ProtoMessage()

func (*ClientTLSSettings) ProtoReflect

func (x *ClientTLSSettings) ProtoReflect() protoreflect.Message

func (*ClientTLSSettings) Reset

func (x *ClientTLSSettings) Reset()

func (*ClientTLSSettings) String

func (x *ClientTLSSettings) String() string

func (*ClientTLSSettings) UnmarshalJSON

func (this *ClientTLSSettings) UnmarshalJSON(b []byte) error

UnmarshalJSON is a custom unmarshaler for ClientTLSSettings

type ClientTLSSettings_TLSmode

type ClientTLSSettings_TLSmode int32

TLS connection mode

const (
	// Do not setup a TLS connection to the upstream endpoint.
	ClientTLSSettings_DISABLE ClientTLSSettings_TLSmode = 0
	// Originate a TLS connection to the upstream endpoint.
	ClientTLSSettings_MUTUAL ClientTLSSettings_TLSmode = 1
	// Secure connections to the upstream using mutual TLS by presenting
	// client certificates for authentication.
	// Compared to Mutual mode, this mode uses certificates generated
	// automatically by Dubbo for mTLS authentication. When this mode is
	// used, all other fields in `ClientTLSSettings` should be empty.
	ClientTLSSettings_DUBBO_MUTUAL ClientTLSSettings_TLSmode = 2
)

func (ClientTLSSettings_TLSmode) Descriptor

func (ClientTLSSettings_TLSmode) Enum

func (ClientTLSSettings_TLSmode) EnumDescriptor deprecated

func (ClientTLSSettings_TLSmode) EnumDescriptor() ([]byte, []int)

Deprecated: Use ClientTLSSettings_TLSmode.Descriptor instead.

func (ClientTLSSettings_TLSmode) Number

func (ClientTLSSettings_TLSmode) String

func (x ClientTLSSettings_TLSmode) String() string

func (ClientTLSSettings_TLSmode) Type

type Destination

type Destination struct {

	// The name of a service from the service registry.
	Host string `protobuf:"bytes,1,opt,name=host,proto3" json:"host,omitempty"`
	// The name of a subset within the service. Applicable only to services
	// within the mesh. The subset must be defined in a corresponding
	// DestinationRule.
	Subset string `protobuf:"bytes,2,opt,name=subset,proto3" json:"subset,omitempty"`
	// contains filtered or unexported fields
}

func (*Destination) DeepCopy

func (in *Destination) DeepCopy() *Destination

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Destination. Required by controller-gen.

func (*Destination) DeepCopyInterface

func (in *Destination) DeepCopyInterface() interface{}

DeepCopyInterface is an autogenerated deepcopy function, copying the receiver, creating a new Destination. Required by controller-gen.

func (*Destination) DeepCopyInto

func (in *Destination) DeepCopyInto(out *Destination)

DeepCopyInto supports using Destination within kubernetes types, where deepcopy-gen is used.

func (*Destination) Descriptor deprecated

func (*Destination) Descriptor() ([]byte, []int)

Deprecated: Use Destination.ProtoReflect.Descriptor instead.

func (*Destination) GetHost

func (x *Destination) GetHost() string

func (*Destination) GetSubset

func (x *Destination) GetSubset() string

func (*Destination) MarshalJSON

func (this *Destination) MarshalJSON() ([]byte, error)

MarshalJSON is a custom marshaler for Destination

func (*Destination) ProtoMessage

func (*Destination) ProtoMessage()

func (*Destination) ProtoReflect

func (x *Destination) ProtoReflect() protoreflect.Message

func (*Destination) Reset

func (x *Destination) Reset()

func (*Destination) String

func (x *Destination) String() string

func (*Destination) UnmarshalJSON

func (this *Destination) UnmarshalJSON(b []byte) error

UnmarshalJSON is a custom unmarshaler for Destination

type DestinationRule

type DestinationRule struct {

	// Note that the host field applies to both HTTP and TCP services
	Host string `protobuf:"bytes,1,opt,name=host,proto3" json:"host,omitempty"`
	// Traffic policies to apply (load balancing policy, connection pool
	// sizes, outlier detection).
	TrafficPolicy *TrafficPolicy `protobuf:"bytes,2,opt,name=traffic_policy,json=trafficPolicy,proto3" json:"traffic_policy,omitempty"`
	// One or more named sets that represent individual versions of a
	// service. Traffic policies can be overridden at subset level.
	Subsets []*Subset `protobuf:"bytes,3,rep,name=subsets,proto3" json:"subsets,omitempty"`
	// A list of namespaces to which this destination rule is exported.
	// The resolution of a destination rule to apply to a service occurs in the
	// context of a hierarchy of namespaces. Exporting a destination rule allows
	// it to be included in the resolution hierarchy for services in
	// other namespaces. This feature provides a mechanism for service owners
	// and mesh administrators to control the visibility of destination rules
	// across namespace boundaries.
	//
	// If no namespaces are specified then the destination rule is exported to all
	// namespaces by default.
	//
	// The value "." is reserved and defines an export to the same namespace that
	// the destination rule is declared in. Similarly, the value "*" is reserved and
	// defines an export to all namespaces.
	ExportTo []string `protobuf:"bytes,4,rep,name=export_to,json=exportTo,proto3" json:"export_to,omitempty"`
	// contains filtered or unexported fields
}

DestinationRule is the internal policy model derived from MeshService.

func (*DestinationRule) DeepCopy

func (in *DestinationRule) DeepCopy() *DestinationRule

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DestinationRule. Required by controller-gen.

func (*DestinationRule) DeepCopyInterface

func (in *DestinationRule) DeepCopyInterface() interface{}

DeepCopyInterface is an autogenerated deepcopy function, copying the receiver, creating a new DestinationRule. Required by controller-gen.

func (*DestinationRule) DeepCopyInto

func (in *DestinationRule) DeepCopyInto(out *DestinationRule)

DeepCopyInto supports using DestinationRule within kubernetes types, where deepcopy-gen is used.

func (*DestinationRule) Descriptor deprecated

func (*DestinationRule) Descriptor() ([]byte, []int)

Deprecated: Use DestinationRule.ProtoReflect.Descriptor instead.

func (*DestinationRule) GetExportTo

func (x *DestinationRule) GetExportTo() []string

func (*DestinationRule) GetHost

func (x *DestinationRule) GetHost() string

func (*DestinationRule) GetSubsets

func (x *DestinationRule) GetSubsets() []*Subset

func (*DestinationRule) GetTrafficPolicy

func (x *DestinationRule) GetTrafficPolicy() *TrafficPolicy

func (*DestinationRule) MarshalJSON

func (this *DestinationRule) MarshalJSON() ([]byte, error)

MarshalJSON is a custom marshaler for DestinationRule

func (*DestinationRule) ProtoMessage

func (*DestinationRule) ProtoMessage()

func (*DestinationRule) ProtoReflect

func (x *DestinationRule) ProtoReflect() protoreflect.Message

func (*DestinationRule) Reset

func (x *DestinationRule) Reset()

func (*DestinationRule) String

func (x *DestinationRule) String() string

func (*DestinationRule) UnmarshalJSON

func (this *DestinationRule) UnmarshalJSON(b []byte) error

UnmarshalJSON is a custom unmarshaler for DestinationRule

type HTTPMatchRequest

type HTTPMatchRequest struct {
	Uri         *StringMatch            `protobuf:"bytes,1,opt,name=uri,proto3" json:"uri,omitempty"`
	Headers     map[string]*StringMatch `` /* 141-byte string literal not displayed */
	Method      *StringMatch            `protobuf:"bytes,3,opt,name=method,proto3" json:"method,omitempty"`
	QueryParams map[string]*StringMatch `` /* 168-byte string literal not displayed */
	Port        uint32                  `protobuf:"varint,5,opt,name=port,proto3" json:"port,omitempty"`
	Host        *StringMatch            `protobuf:"bytes,6,opt,name=host,proto3" json:"host,omitempty"`
	// contains filtered or unexported fields
}

func (*HTTPMatchRequest) DeepCopy

func (in *HTTPMatchRequest) DeepCopy() *HTTPMatchRequest

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HTTPMatchRequest. Required by controller-gen.

func (*HTTPMatchRequest) DeepCopyInterface

func (in *HTTPMatchRequest) DeepCopyInterface() interface{}

DeepCopyInterface is an autogenerated deepcopy function, copying the receiver, creating a new HTTPMatchRequest. Required by controller-gen.

func (*HTTPMatchRequest) DeepCopyInto

func (in *HTTPMatchRequest) DeepCopyInto(out *HTTPMatchRequest)

DeepCopyInto supports using HTTPMatchRequest within kubernetes types, where deepcopy-gen is used.

func (*HTTPMatchRequest) Descriptor deprecated

func (*HTTPMatchRequest) Descriptor() ([]byte, []int)

Deprecated: Use HTTPMatchRequest.ProtoReflect.Descriptor instead.

func (*HTTPMatchRequest) GetHeaders

func (x *HTTPMatchRequest) GetHeaders() map[string]*StringMatch

func (*HTTPMatchRequest) GetHost

func (x *HTTPMatchRequest) GetHost() *StringMatch

func (*HTTPMatchRequest) GetMethod

func (x *HTTPMatchRequest) GetMethod() *StringMatch

func (*HTTPMatchRequest) GetPort

func (x *HTTPMatchRequest) GetPort() uint32

func (*HTTPMatchRequest) GetQueryParams

func (x *HTTPMatchRequest) GetQueryParams() map[string]*StringMatch

func (*HTTPMatchRequest) GetUri

func (x *HTTPMatchRequest) GetUri() *StringMatch

func (*HTTPMatchRequest) MarshalJSON

func (this *HTTPMatchRequest) MarshalJSON() ([]byte, error)

MarshalJSON is a custom marshaler for HTTPMatchRequest

func (*HTTPMatchRequest) ProtoMessage

func (*HTTPMatchRequest) ProtoMessage()

func (*HTTPMatchRequest) ProtoReflect

func (x *HTTPMatchRequest) ProtoReflect() protoreflect.Message

func (*HTTPMatchRequest) Reset

func (x *HTTPMatchRequest) Reset()

func (*HTTPMatchRequest) String

func (x *HTTPMatchRequest) String() string

func (*HTTPMatchRequest) UnmarshalJSON

func (this *HTTPMatchRequest) UnmarshalJSON(b []byte) error

UnmarshalJSON is a custom unmarshaler for HTTPMatchRequest

type HTTPRoute

type HTTPRoute struct {

	// Match conditions to be satisfied for the rule to be activated.
	// Multiple match entries are ORed; fields inside one match entry are ANDed.
	Match []*HTTPMatchRequest `protobuf:"bytes,2,rep,name=match,proto3" json:"match,omitempty"`
	// A HTTP rule can either return a direct_response, redirect or forward (default) traffic.
	// The forwarding target can be one of several versions of a service (see
	// glossary in beginning of document). Weights associated with the
	// service version determine the proportion of traffic it receives.
	Route []*HTTPRouteDestination `protobuf:"bytes,1,rep,name=route,proto3" json:"route,omitempty"`
	// contains filtered or unexported fields
}

Describes match conditions and actions for routing HTTP/1.1, HTTP2, and gRPC traffic. See VirtualService for usage examples.

func (*HTTPRoute) DeepCopy

func (in *HTTPRoute) DeepCopy() *HTTPRoute

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HTTPRoute. Required by controller-gen.

func (*HTTPRoute) DeepCopyInterface

func (in *HTTPRoute) DeepCopyInterface() interface{}

DeepCopyInterface is an autogenerated deepcopy function, copying the receiver, creating a new HTTPRoute. Required by controller-gen.

func (*HTTPRoute) DeepCopyInto

func (in *HTTPRoute) DeepCopyInto(out *HTTPRoute)

DeepCopyInto supports using HTTPRoute within kubernetes types, where deepcopy-gen is used.

func (*HTTPRoute) Descriptor deprecated

func (*HTTPRoute) Descriptor() ([]byte, []int)

Deprecated: Use HTTPRoute.ProtoReflect.Descriptor instead.

func (*HTTPRoute) GetMatch

func (x *HTTPRoute) GetMatch() []*HTTPMatchRequest

func (*HTTPRoute) GetRoute

func (x *HTTPRoute) GetRoute() []*HTTPRouteDestination

func (*HTTPRoute) MarshalJSON

func (this *HTTPRoute) MarshalJSON() ([]byte, error)

MarshalJSON is a custom marshaler for HTTPRoute

func (*HTTPRoute) ProtoMessage

func (*HTTPRoute) ProtoMessage()

func (*HTTPRoute) ProtoReflect

func (x *HTTPRoute) ProtoReflect() protoreflect.Message

func (*HTTPRoute) Reset

func (x *HTTPRoute) Reset()

func (*HTTPRoute) String

func (x *HTTPRoute) String() string

func (*HTTPRoute) UnmarshalJSON

func (this *HTTPRoute) UnmarshalJSON(b []byte) error

UnmarshalJSON is a custom unmarshaler for HTTPRoute

type HTTPRouteDestination

type HTTPRouteDestination struct {

	// Destination uniquely identifies the instances of a service
	// to which the request/connection should be forwarded to.
	Destination *Destination `protobuf:"bytes,1,opt,name=destination,proto3" json:"destination,omitempty"`
	// Weight specifies the relative proportion of traffic to be forwarded to the destination. A destination will receive `weight/(sum of all weights)` requests.
	// If there is only one destination in a rule, it will receive all traffic.
	// Otherwise, if weight is `0`, the destination will not receive any traffic.
	Weight int32 `protobuf:"varint,2,opt,name=weight,proto3" json:"weight,omitempty"`
	// contains filtered or unexported fields
}

func (*HTTPRouteDestination) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HTTPRouteDestination. Required by controller-gen.

func (*HTTPRouteDestination) DeepCopyInterface

func (in *HTTPRouteDestination) DeepCopyInterface() interface{}

DeepCopyInterface is an autogenerated deepcopy function, copying the receiver, creating a new HTTPRouteDestination. Required by controller-gen.

func (*HTTPRouteDestination) DeepCopyInto

func (in *HTTPRouteDestination) DeepCopyInto(out *HTTPRouteDestination)

DeepCopyInto supports using HTTPRouteDestination within kubernetes types, where deepcopy-gen is used.

func (*HTTPRouteDestination) Descriptor deprecated

func (*HTTPRouteDestination) Descriptor() ([]byte, []int)

Deprecated: Use HTTPRouteDestination.ProtoReflect.Descriptor instead.

func (*HTTPRouteDestination) GetDestination

func (x *HTTPRouteDestination) GetDestination() *Destination

func (*HTTPRouteDestination) GetWeight

func (x *HTTPRouteDestination) GetWeight() int32

func (*HTTPRouteDestination) MarshalJSON

func (this *HTTPRouteDestination) MarshalJSON() ([]byte, error)

MarshalJSON is a custom marshaler for HTTPRouteDestination

func (*HTTPRouteDestination) ProtoMessage

func (*HTTPRouteDestination) ProtoMessage()

func (*HTTPRouteDestination) ProtoReflect

func (x *HTTPRouteDestination) ProtoReflect() protoreflect.Message

func (*HTTPRouteDestination) Reset

func (x *HTTPRouteDestination) Reset()

func (*HTTPRouteDestination) String

func (x *HTTPRouteDestination) String() string

func (*HTTPRouteDestination) UnmarshalJSON

func (this *HTTPRouteDestination) UnmarshalJSON(b []byte) error

UnmarshalJSON is a custom unmarshaler for HTTPRouteDestination

type MeshService

type MeshService struct {

	// Hosts addressed by this service-to-service policy.
	Hosts []string `protobuf:"bytes,1,rep,name=hosts,proto3" json:"hosts,omitempty"`
	// Ordered routing rules. Place exact rules first, broad rules next, and fallback routes last.
	Rules []*MeshServiceRule `protobuf:"bytes,3,rep,name=rules,proto3" json:"rules,omitempty"`
	// Ordered fallback route entries. This field keeps older service-weight routing manifests working.
	Routes []*MeshServiceRoute `protobuf:"bytes,4,rep,name=routes,proto3" json:"routes,omitempty"`
	// Default traffic policy for every destination in this MeshService.
	TrafficPolicy *TrafficPolicy `protobuf:"bytes,5,opt,name=traffic_policy,json=trafficPolicy,proto3" json:"traffic_policy,omitempty"`
	// contains filtered or unexported fields
}

MeshService combines route rules and traffic policies for service-to-service traffic.

<!-- crd generation tags +cue-gen:MeshService:groupName:networking.dubbo.apache.org +cue-gen:MeshService:versions:v1alpha3 +cue-gen:MeshService:annotations:helm.sh/resource-policy=keep +cue-gen:MeshService:labels:app=dubbo,chart=dubbo,heritage=Tiller,release=dubbo +cue-gen:MeshService:subresource:status +cue-gen:MeshService:scope:Namespaced +cue-gen:MeshService:resource:categories=dubbo,networking,shortNames=ms +cue-gen:MeshService:printerColumn:name=Hosts,type=string,JSONPath=.spec.hosts,description="The destination hosts to which service traffic is being sent" +cue-gen:MeshService:printerColumn:name=Age,type=date,JSONPath=.metadata.creationTimestamp,description="CreationTimestamp is a timestamp representing the server time when this object was created. It is not guaranteed to be set in happens-before order across separate operations. Clients may not set this value. It is represented in RFC3339 form and is in UTC. Populated by the system. Read-only. Null for lists. More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#metadata" +cue-gen:MeshService:preserveUnknownFields:false -->

<!-- go code generation tags +kubetype-gen +kubetype-gen:groupVersion=networking.dubbo.apache.org/v1alpha3 +genclient +k8s:deepcopy-gen=true -->

func (*MeshService) DeepCopy

func (in *MeshService) DeepCopy() *MeshService

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MeshService. Required by controller-gen.

func (*MeshService) DeepCopyInterface

func (in *MeshService) DeepCopyInterface() interface{}

DeepCopyInterface is an autogenerated deepcopy function, copying the receiver, creating a new MeshService. Required by controller-gen.

func (*MeshService) DeepCopyInto

func (in *MeshService) DeepCopyInto(out *MeshService)

DeepCopyInto supports using MeshService within kubernetes types, where deepcopy-gen is used.

func (*MeshService) Descriptor deprecated

func (*MeshService) Descriptor() ([]byte, []int)

Deprecated: Use MeshService.ProtoReflect.Descriptor instead.

func (*MeshService) GetHosts

func (x *MeshService) GetHosts() []string

func (*MeshService) GetRoutes

func (x *MeshService) GetRoutes() []*MeshServiceRoute

func (*MeshService) GetRules

func (x *MeshService) GetRules() []*MeshServiceRule

func (*MeshService) GetTrafficPolicy

func (x *MeshService) GetTrafficPolicy() *TrafficPolicy

func (*MeshService) MarshalJSON

func (this *MeshService) MarshalJSON() ([]byte, error)

MarshalJSON is a custom marshaler for MeshService

func (*MeshService) ProtoMessage

func (*MeshService) ProtoMessage()

func (*MeshService) ProtoReflect

func (x *MeshService) ProtoReflect() protoreflect.Message

func (*MeshService) Reset

func (x *MeshService) Reset()

func (*MeshService) String

func (x *MeshService) String() string

func (*MeshService) UnmarshalJSON

func (this *MeshService) UnmarshalJSON(b []byte) error

UnmarshalJSON is a custom unmarshaler for MeshService

type MeshServiceRoute

type MeshServiceRoute struct {

	// One route entry can split traffic across multiple service destinations.
	Service []*ServiceDestination `protobuf:"bytes,1,rep,name=service,proto3" json:"service,omitempty"`
	// contains filtered or unexported fields
}

func (*MeshServiceRoute) DeepCopy

func (in *MeshServiceRoute) DeepCopy() *MeshServiceRoute

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MeshServiceRoute. Required by controller-gen.

func (*MeshServiceRoute) DeepCopyInterface

func (in *MeshServiceRoute) DeepCopyInterface() interface{}

DeepCopyInterface is an autogenerated deepcopy function, copying the receiver, creating a new MeshServiceRoute. Required by controller-gen.

func (*MeshServiceRoute) DeepCopyInto

func (in *MeshServiceRoute) DeepCopyInto(out *MeshServiceRoute)

DeepCopyInto supports using MeshServiceRoute within kubernetes types, where deepcopy-gen is used.

func (*MeshServiceRoute) Descriptor deprecated

func (*MeshServiceRoute) Descriptor() ([]byte, []int)

Deprecated: Use MeshServiceRoute.ProtoReflect.Descriptor instead.

func (*MeshServiceRoute) GetService

func (x *MeshServiceRoute) GetService() []*ServiceDestination

func (*MeshServiceRoute) MarshalJSON

func (this *MeshServiceRoute) MarshalJSON() ([]byte, error)

MarshalJSON is a custom marshaler for MeshServiceRoute

func (*MeshServiceRoute) ProtoMessage

func (*MeshServiceRoute) ProtoMessage()

func (*MeshServiceRoute) ProtoReflect

func (x *MeshServiceRoute) ProtoReflect() protoreflect.Message

func (*MeshServiceRoute) Reset

func (x *MeshServiceRoute) Reset()

func (*MeshServiceRoute) String

func (x *MeshServiceRoute) String() string

func (*MeshServiceRoute) UnmarshalJSON

func (this *MeshServiceRoute) UnmarshalJSON(b []byte) error

UnmarshalJSON is a custom unmarshaler for MeshServiceRoute

type MeshServiceRule

type MeshServiceRule struct {

	// Match conditions for the primary route entries.
	Match []*HTTPMatchRequest `protobuf:"bytes,1,rep,name=match,proto3" json:"match,omitempty"`
	// Primary route entries used when match conditions are satisfied.
	Route []*MeshServiceRoute `protobuf:"bytes,2,rep,name=route,proto3" json:"route,omitempty"`
	// Fallback route entries used after primary match-specific routes.
	Routes []*MeshServiceRoute `protobuf:"bytes,3,rep,name=routes,proto3" json:"routes,omitempty"`
	// contains filtered or unexported fields
}

func (*MeshServiceRule) DeepCopy

func (in *MeshServiceRule) DeepCopy() *MeshServiceRule

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MeshServiceRule. Required by controller-gen.

func (*MeshServiceRule) DeepCopyInterface

func (in *MeshServiceRule) DeepCopyInterface() interface{}

DeepCopyInterface is an autogenerated deepcopy function, copying the receiver, creating a new MeshServiceRule. Required by controller-gen.

func (*MeshServiceRule) DeepCopyInto

func (in *MeshServiceRule) DeepCopyInto(out *MeshServiceRule)

DeepCopyInto supports using MeshServiceRule within kubernetes types, where deepcopy-gen is used.

func (*MeshServiceRule) Descriptor deprecated

func (*MeshServiceRule) Descriptor() ([]byte, []int)

Deprecated: Use MeshServiceRule.ProtoReflect.Descriptor instead.

func (*MeshServiceRule) GetMatch

func (x *MeshServiceRule) GetMatch() []*HTTPMatchRequest

func (*MeshServiceRule) GetRoute

func (x *MeshServiceRule) GetRoute() []*MeshServiceRoute

func (*MeshServiceRule) GetRoutes

func (x *MeshServiceRule) GetRoutes() []*MeshServiceRoute

func (*MeshServiceRule) MarshalJSON

func (this *MeshServiceRule) MarshalJSON() ([]byte, error)

MarshalJSON is a custom marshaler for MeshServiceRule

func (*MeshServiceRule) ProtoMessage

func (*MeshServiceRule) ProtoMessage()

func (*MeshServiceRule) ProtoReflect

func (x *MeshServiceRule) ProtoReflect() protoreflect.Message

func (*MeshServiceRule) Reset

func (x *MeshServiceRule) Reset()

func (*MeshServiceRule) String

func (x *MeshServiceRule) String() string

func (*MeshServiceRule) UnmarshalJSON

func (this *MeshServiceRule) UnmarshalJSON(b []byte) error

UnmarshalJSON is a custom unmarshaler for MeshServiceRule

type ServiceDestination

type ServiceDestination struct {

	// Name is the target Kubernetes Service for service-based traffic splitting. When labels are set, name is used as the subset name.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Host is the host addressed by this route policy. Label-based destinations use host plus labels; service-based destinations resolve name to the target Service host.
	Host string       `protobuf:"bytes,2,opt,name=host,proto3" json:"host,omitempty"`
	Port *ServicePort `protobuf:"bytes,3,opt,name=port,proto3" json:"port,omitempty"`
	// Labels select a subset of endpoints behind host. If labels are empty, traffic is split by service name instead of endpoint labels.
	Labels        map[string]string `` /* 139-byte string literal not displayed */
	Weight        int32             `protobuf:"varint,5,opt,name=weight,proto3" json:"weight,omitempty"`
	TrafficPolicy *TrafficPolicy    `protobuf:"bytes,6,opt,name=traffic_policy,json=trafficPolicy,proto3" json:"traffic_policy,omitempty"`
	// contains filtered or unexported fields
}

func (*ServiceDestination) DeepCopy

func (in *ServiceDestination) DeepCopy() *ServiceDestination

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServiceDestination. Required by controller-gen.

func (*ServiceDestination) DeepCopyInterface

func (in *ServiceDestination) DeepCopyInterface() interface{}

DeepCopyInterface is an autogenerated deepcopy function, copying the receiver, creating a new ServiceDestination. Required by controller-gen.

func (*ServiceDestination) DeepCopyInto

func (in *ServiceDestination) DeepCopyInto(out *ServiceDestination)

DeepCopyInto supports using ServiceDestination within kubernetes types, where deepcopy-gen is used.

func (*ServiceDestination) Descriptor deprecated

func (*ServiceDestination) Descriptor() ([]byte, []int)

Deprecated: Use ServiceDestination.ProtoReflect.Descriptor instead.

func (*ServiceDestination) GetHost

func (x *ServiceDestination) GetHost() string

func (*ServiceDestination) GetLabels

func (x *ServiceDestination) GetLabels() map[string]string

func (*ServiceDestination) GetName

func (x *ServiceDestination) GetName() string

func (*ServiceDestination) GetPort

func (x *ServiceDestination) GetPort() *ServicePort

func (*ServiceDestination) GetTrafficPolicy

func (x *ServiceDestination) GetTrafficPolicy() *TrafficPolicy

func (*ServiceDestination) GetWeight

func (x *ServiceDestination) GetWeight() int32

func (*ServiceDestination) MarshalJSON

func (this *ServiceDestination) MarshalJSON() ([]byte, error)

MarshalJSON is a custom marshaler for ServiceDestination

func (*ServiceDestination) ProtoMessage

func (*ServiceDestination) ProtoMessage()

func (*ServiceDestination) ProtoReflect

func (x *ServiceDestination) ProtoReflect() protoreflect.Message

func (*ServiceDestination) Reset

func (x *ServiceDestination) Reset()

func (*ServiceDestination) String

func (x *ServiceDestination) String() string

func (*ServiceDestination) UnmarshalJSON

func (this *ServiceDestination) UnmarshalJSON(b []byte) error

UnmarshalJSON is a custom unmarshaler for ServiceDestination

type ServicePort

type ServicePort struct {
	Number uint32 `protobuf:"varint,1,opt,name=number,proto3" json:"number,omitempty"`
	Name   string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

func (*ServicePort) DeepCopy

func (in *ServicePort) DeepCopy() *ServicePort

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServicePort. Required by controller-gen.

func (*ServicePort) DeepCopyInterface

func (in *ServicePort) DeepCopyInterface() interface{}

DeepCopyInterface is an autogenerated deepcopy function, copying the receiver, creating a new ServicePort. Required by controller-gen.

func (*ServicePort) DeepCopyInto

func (in *ServicePort) DeepCopyInto(out *ServicePort)

DeepCopyInto supports using ServicePort within kubernetes types, where deepcopy-gen is used.

func (*ServicePort) Descriptor deprecated

func (*ServicePort) Descriptor() ([]byte, []int)

Deprecated: Use ServicePort.ProtoReflect.Descriptor instead.

func (*ServicePort) GetName

func (x *ServicePort) GetName() string

func (*ServicePort) GetNumber

func (x *ServicePort) GetNumber() uint32

func (*ServicePort) MarshalJSON

func (this *ServicePort) MarshalJSON() ([]byte, error)

MarshalJSON is a custom marshaler for ServicePort

func (*ServicePort) ProtoMessage

func (*ServicePort) ProtoMessage()

func (*ServicePort) ProtoReflect

func (x *ServicePort) ProtoReflect() protoreflect.Message

func (*ServicePort) Reset

func (x *ServicePort) Reset()

func (*ServicePort) String

func (x *ServicePort) String() string

func (*ServicePort) UnmarshalJSON

func (this *ServicePort) UnmarshalJSON(b []byte) error

UnmarshalJSON is a custom unmarshaler for ServicePort

type StringMatch

type StringMatch struct {

	// Types that are valid to be assigned to MatchType:
	//
	//	*StringMatch_Exact
	//	*StringMatch_Prefix
	//	*StringMatch_Regex
	MatchType isStringMatch_MatchType `protobuf_oneof:"match_type"`
	// contains filtered or unexported fields
}

func (*StringMatch) DeepCopy

func (in *StringMatch) DeepCopy() *StringMatch

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new StringMatch. Required by controller-gen.

func (*StringMatch) DeepCopyInterface

func (in *StringMatch) DeepCopyInterface() interface{}

DeepCopyInterface is an autogenerated deepcopy function, copying the receiver, creating a new StringMatch. Required by controller-gen.

func (*StringMatch) DeepCopyInto

func (in *StringMatch) DeepCopyInto(out *StringMatch)

DeepCopyInto supports using StringMatch within kubernetes types, where deepcopy-gen is used.

func (*StringMatch) Descriptor deprecated

func (*StringMatch) Descriptor() ([]byte, []int)

Deprecated: Use StringMatch.ProtoReflect.Descriptor instead.

func (*StringMatch) GetExact

func (x *StringMatch) GetExact() string

func (*StringMatch) GetMatchType

func (x *StringMatch) GetMatchType() isStringMatch_MatchType

func (*StringMatch) GetPrefix

func (x *StringMatch) GetPrefix() string

func (*StringMatch) GetRegex

func (x *StringMatch) GetRegex() string

func (*StringMatch) MarshalJSON

func (this *StringMatch) MarshalJSON() ([]byte, error)

MarshalJSON is a custom marshaler for StringMatch

func (*StringMatch) ProtoMessage

func (*StringMatch) ProtoMessage()

func (*StringMatch) ProtoReflect

func (x *StringMatch) ProtoReflect() protoreflect.Message

func (*StringMatch) Reset

func (x *StringMatch) Reset()

func (*StringMatch) String

func (x *StringMatch) String() string

func (*StringMatch) UnmarshalJSON

func (this *StringMatch) UnmarshalJSON(b []byte) error

UnmarshalJSON is a custom unmarshaler for StringMatch

type StringMatch_Exact

type StringMatch_Exact struct {
	Exact string `protobuf:"bytes,1,opt,name=exact,proto3,oneof"`
}

type StringMatch_Prefix

type StringMatch_Prefix struct {
	Prefix string `protobuf:"bytes,2,opt,name=prefix,proto3,oneof"`
}

type StringMatch_Regex

type StringMatch_Regex struct {
	Regex string `protobuf:"bytes,3,opt,name=regex,proto3,oneof"`
}

type Subset

type Subset struct {

	// Name of the subset. The service name and the subset name can
	// be used for traffic splitting in a route rule.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Labels apply a filter over the endpoints of a service in the
	// service registry. See route rules for examples of usage.
	Labels map[string]string `` /* 139-byte string literal not displayed */
	// Traffic policies that apply to this subset. Subsets inherit the
	// traffic policies specified at the DestinationRule level. Settings
	// specified at the subset level will override the corresponding settings
	// specified at the DestinationRule level.
	TrafficPolicy *TrafficPolicy `protobuf:"bytes,3,opt,name=traffic_policy,json=trafficPolicy,proto3" json:"traffic_policy,omitempty"`
	// contains filtered or unexported fields
}

func (*Subset) DeepCopy

func (in *Subset) DeepCopy() *Subset

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Subset. Required by controller-gen.

func (*Subset) DeepCopyInterface

func (in *Subset) DeepCopyInterface() interface{}

DeepCopyInterface is an autogenerated deepcopy function, copying the receiver, creating a new Subset. Required by controller-gen.

func (*Subset) DeepCopyInto

func (in *Subset) DeepCopyInto(out *Subset)

DeepCopyInto supports using Subset within kubernetes types, where deepcopy-gen is used.

func (*Subset) Descriptor deprecated

func (*Subset) Descriptor() ([]byte, []int)

Deprecated: Use Subset.ProtoReflect.Descriptor instead.

func (*Subset) GetLabels

func (x *Subset) GetLabels() map[string]string

func (*Subset) GetName

func (x *Subset) GetName() string

func (*Subset) GetTrafficPolicy

func (x *Subset) GetTrafficPolicy() *TrafficPolicy

func (*Subset) MarshalJSON

func (this *Subset) MarshalJSON() ([]byte, error)

MarshalJSON is a custom marshaler for Subset

func (*Subset) ProtoMessage

func (*Subset) ProtoMessage()

func (*Subset) ProtoReflect

func (x *Subset) ProtoReflect() protoreflect.Message

func (*Subset) Reset

func (x *Subset) Reset()

func (*Subset) String

func (x *Subset) String() string

func (*Subset) UnmarshalJSON

func (this *Subset) UnmarshalJSON(b []byte) error

UnmarshalJSON is a custom unmarshaler for Subset

type TrafficPolicy

type TrafficPolicy struct {

	// TLS related settings for connections to the upstream service.
	Tls *ClientTLSSettings `protobuf:"bytes,1,opt,name=tls,proto3" json:"tls,omitempty"`
	// contains filtered or unexported fields
}

Traffic policies to apply for a specific destination, across all destination ports. See DestinationRule for examples.

func (*TrafficPolicy) DeepCopy

func (in *TrafficPolicy) DeepCopy() *TrafficPolicy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TrafficPolicy. Required by controller-gen.

func (*TrafficPolicy) DeepCopyInterface

func (in *TrafficPolicy) DeepCopyInterface() interface{}

DeepCopyInterface is an autogenerated deepcopy function, copying the receiver, creating a new TrafficPolicy. Required by controller-gen.

func (*TrafficPolicy) DeepCopyInto

func (in *TrafficPolicy) DeepCopyInto(out *TrafficPolicy)

DeepCopyInto supports using TrafficPolicy within kubernetes types, where deepcopy-gen is used.

func (*TrafficPolicy) Descriptor deprecated

func (*TrafficPolicy) Descriptor() ([]byte, []int)

Deprecated: Use TrafficPolicy.ProtoReflect.Descriptor instead.

func (*TrafficPolicy) GetTls

func (x *TrafficPolicy) GetTls() *ClientTLSSettings

func (*TrafficPolicy) MarshalJSON

func (this *TrafficPolicy) MarshalJSON() ([]byte, error)

MarshalJSON is a custom marshaler for TrafficPolicy

func (*TrafficPolicy) ProtoMessage

func (*TrafficPolicy) ProtoMessage()

func (*TrafficPolicy) ProtoReflect

func (x *TrafficPolicy) ProtoReflect() protoreflect.Message

func (*TrafficPolicy) Reset

func (x *TrafficPolicy) Reset()

func (*TrafficPolicy) String

func (x *TrafficPolicy) String() string

func (*TrafficPolicy) UnmarshalJSON

func (this *TrafficPolicy) UnmarshalJSON(b []byte) error

UnmarshalJSON is a custom unmarshaler for TrafficPolicy

type VirtualService

type VirtualService struct {

	// The hosts field applies to both HTTP and TCP services. Service inside
	// the mesh, i.e., those found in the service registry, must always be
	// referred to using their alphanumeric names.
	Hosts []string `protobuf:"bytes,1,rep,name=hosts,proto3" json:"hosts,omitempty"`
	// An ordered list of route rules for HTTP traffic.
	Http []*HTTPRoute `protobuf:"bytes,2,rep,name=http,proto3" json:"http,omitempty"`
	// A list of namespaces to which this virtual service is exported. Exporting a
	// virtual service allows it to be used by sidecars and gateways defined in
	// other namespaces. This feature provides a mechanism for service owners
	// and mesh administrators to control the visibility of virtual services
	// across namespace boundaries.
	//
	// If no namespaces are specified then the virtual service is exported to all
	// namespaces by default.
	//
	// The value "." is reserved and defines an export to the same namespace that
	// the virtual service is declared in. Similarly the value "*" is reserved and
	// defines an export to all namespaces.
	ExportTo []string `protobuf:"bytes,3,rep,name=export_to,json=exportTo,proto3" json:"export_to,omitempty"`
	// contains filtered or unexported fields
}

VirtualService is the internal route model derived from MeshService.

func (*VirtualService) DeepCopy

func (in *VirtualService) DeepCopy() *VirtualService

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VirtualService. Required by controller-gen.

func (*VirtualService) DeepCopyInterface

func (in *VirtualService) DeepCopyInterface() interface{}

DeepCopyInterface is an autogenerated deepcopy function, copying the receiver, creating a new VirtualService. Required by controller-gen.

func (*VirtualService) DeepCopyInto

func (in *VirtualService) DeepCopyInto(out *VirtualService)

DeepCopyInto supports using VirtualService within kubernetes types, where deepcopy-gen is used.

func (*VirtualService) Descriptor deprecated

func (*VirtualService) Descriptor() ([]byte, []int)

Deprecated: Use VirtualService.ProtoReflect.Descriptor instead.

func (*VirtualService) GetExportTo

func (x *VirtualService) GetExportTo() []string

func (*VirtualService) GetHosts

func (x *VirtualService) GetHosts() []string

func (*VirtualService) GetHttp

func (x *VirtualService) GetHttp() []*HTTPRoute

func (*VirtualService) MarshalJSON

func (this *VirtualService) MarshalJSON() ([]byte, error)

MarshalJSON is a custom marshaler for VirtualService

func (*VirtualService) ProtoMessage

func (*VirtualService) ProtoMessage()

func (*VirtualService) ProtoReflect

func (x *VirtualService) ProtoReflect() protoreflect.Message

func (*VirtualService) Reset

func (x *VirtualService) Reset()

func (*VirtualService) String

func (x *VirtualService) String() string

func (*VirtualService) UnmarshalJSON

func (this *VirtualService) UnmarshalJSON(b []byte) error

UnmarshalJSON is a custom unmarshaler for VirtualService

Jump to